@@ -20,8 +20,7 @@ gint      ggv_default_height = DEFAULT_WINDOW_HEIGHT;
 
 gboolean ggv_panel = TRUE, ggv_menubar = TRUE, ggv_toolbar = TRUE;
 gboolean ggv_statusbar = TRUE, ggv_autojump = TRUE, ggv_pageflip = FALSE;
-GgvToolbarStyle ggv_toolbar_style = GGV_TOOLBAR_STYLE_DEFAULT;
-gboolean ggv_right_panel = FALSE;
+gboolean ggv_right_panel = FALSE, ggv_watch_doc = TRUE;
 
 gint ggv_unit_index = 0;
 
@@ -51,9 +50,6 @@ ggv_prefs_load()
 	ggv_toolbar = gconf_client_get_bool(gconf_client,
                                            "/apps/ggv/layout/showtoolbar",
                                            NULL);
-        ggv_toolbar_style = gconf_client_get_int(gconf_client,
-                                                 "/apps/ggv/layout/toolbarstyle",
-                                                 NULL);
         ggv_menubar = gconf_client_get_bool(gconf_client,
                                            "/apps/ggv/layout/showmenubar",
                                            NULL);
@@ -69,6 +65,9 @@ ggv_prefs_load()
         ggv_right_panel = gconf_client_get_bool(gconf_client,
                                                "/apps/ggv/layout/rightpanel",
                                                NULL);
+        ggv_watch_doc = gconf_client_get_bool(gconf_client,
+                                              "/apps/ggv/gtkgs/watch_doc",
+                                              NULL);
         /* Get geometry */
         ggv_save_geometry = gconf_client_get_bool
                 (gconf_client, "/apps/ggv/layout/savegeometry", NULL);
@@ -110,11 +109,6 @@ ggv_prefs_changed(GConfClient* client, guint cnxn_id,
                                                     "/apps/ggv/layout/showstatusbar",
                                                     NULL);
         }
-        else if(!strcmp(entry->key, "/apps/ggv/layout/toolbarstyle")) {
-                ggv_toolbar_style = gconf_client_get_int(client,
-                                                         "/apps/ggv/layout/toolbarstyle",
-                                                         NULL);
-        }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showmenubar")) {
                 ggv_menubar = gconf_client_get_bool(client,
                                                     "/apps/ggv/layout/showmenubar",
@@ -149,6 +143,10 @@ ggv_prefs_changed(GConfClient* client, guint cnxn_id,
                     (client, "/apps/ggv/layout/windowheight", NULL)) == 0)
                         ggv_default_height = DEFAULT_WINDOW_HEIGHT;
         }
+        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/watch_doc")) {
+                ggv_watch_doc = gconf_client_get_bool
+                        (client, "/apps/ggv/gtkgs/watch_doc", NULL);
+        }
 }
 
 GConfClient *
