@@ -24,6 +24,7 @@
 #include "ggv-window.h"
 #include "ggv-prefs.h"
 #include "ggvutils.h"
+#include "ggv-recent.h"
 
 #define BONOBO_DEBUG
 
@@ -231,8 +232,12 @@ main(int argc, char **argv)
 
         gtk_idle_add (create_windows_from_cmdline, &ctx);
 
+	/*Init Stock Icons*/
+	ggv_init_stock_icons ();
+
 	gnome_window_icon_set_default_from_file (GNOMEICONDIR "/gnome-ghostview.png");
 
+	ggv_recent_init ();
         ggv_prefs_load();
 
         if(read_stdin) {
